Package: TeachingDemos
Title: Demonstrations for Teaching and Learning
Version: 2.13
Author: Greg Snow
Description: Demonstration functions that can be used in a classroom to demonstrate statistical concepts, or on your own to better understand the concepts or the programming.
Maintainer: Greg Snow <538280@gmail.com>
License: Artistic-2.0
Date: 2024-02-13
Suggests: tkrplot, lattice, MASS, rgl, tcltk, tcltk2, png, ggplot2,
        logspline, spData, sf
Enhances: manipulate, R2wd
LazyData: true
KeepSource: true
NeedsCompilation: no
Packaged: 2024-02-16 21:07:53 UTC; gls33
Repository: CRAN
Date/Publication: 2024-02-16 23:10:11 UTC
Built: R 4.6.0; ; 2026-04-26 12:46:52 UTC; unix
